.. change::
    :tags: bug, orm, regression
    :tickets: 11562
    :versions: 2.0.32

    Fixed regression going back to 1.4 where accessing a collection using the
    "dynamic" strategy on a transient object and attempting to query would
    raise an internal error rather than the expected :class:`.NoResultFound`
    that occurred in 1.3.
